@@ -2,6 +2,7 @@
 #include <iostream>
 #include <QtGui>
 
+#include "install_dialog.h"
 #include "mainwindow.h"
 
 int main(int argc, char** argv)
@@ -9,6 +10,8 @@ int main(int argc, char** argv)
 	QApplication app(argc, argv);
 	QCoreApplication::setOrganizationName("KatanaSoft");
 	QCoreApplication::setApplicationName("Katana");
+	if (!installTranslationIfNecessary())
+		return 1;
 	MainWindow window;
 	window.show();
 	return app.exec();
