@@ -25,6 +25,11 @@ protected:
 
 	void replaceViewer(InfiniteScrollViewer* viewer);
 
+	void setLandscape();
+	void setPortrait();
+
+	bool event(QEvent* ev);
+
 	virtual void keyPressEvent(QKeyEvent* event);
 	void selectVerse(QString startingFilter);
 	void search(QString text, QString scope);
@@ -40,6 +45,7 @@ protected slots:
 	void onSearch();
 	void onSettings();
 	void goToVerse(QString verse);
+	void orientationChanged(const QString& newOrientation);
 
 private:
 	BibleInfo* mBible;
